@@ -1,51 +1,57 @@
-"""
-Modules related to chemistry of periodic-table elements
-"""
+"""Modules related to chemistry of periodic-table elements."""
 
 import os
 import json
 import numpy as np
+import functools
 
-el_chem_json_file = str(os.path.join(os.path.dirname(__file__), "Elements.json"))
+el_chem_json_file = str(
+    os.path.join(os.path.dirname(__file__), "Elements.json")
+)
 el_chem_json = open(el_chem_json_file, "r")
 chem_data = json.load(el_chem_json)
 el_chem_json.close()
 
-el_chrg_json_file = str(os.path.join(os.path.dirname(__file__), "element_charge.json"))
+el_chrg_json_file = str(
+    os.path.join(os.path.dirname(__file__), "element_charge.json")
+)
 el_chrg_json = open(el_chrg_json_file, "r")
 chrg_data = json.load(el_chrg_json)
 el_chrg_json.close()
+cgcnn_feature_json = os.path.join(os.path.dirname(__file__), "atom_init.json")
 
 
 def get_descrp_arr_name(elm="Al"):
     """
-      Get chemical descriptors for an element
-      
-      Args:
-      
+    Get chemical descriptors for an element.
+
+    Can be used in JARVIS-ML.
+
+    Args:
+
            elm: element name
-           
-      Returns:
-      
+
+    Returns:
              arr: array value
-      """
+    """
     arr = []
     try:
         dat = chem_data
-
         d = dat[elm]
         arr = []
         for k, v in d.items():
             arr.append(k)
-    except:
+    except Exception:
         pass
     return arr
 
 
 class Specie(object):
     """
-    Specie object for chemistry information
-    
+    Specie object for chemistry information.
+
+    Used in defining chemistry of a material.
+
     >>> el = Specie('Al')
     >>> el.Z
     13
@@ -60,38 +66,36 @@ class Specie(object):
     >>> el = Specie('asdfg')
     >>> el.element_property("asdfg")
     nan
-    
+
     """
 
     def __init__(self, symbol=""):
+        """Initialize with periodic table element."""
         self.symbol = symbol
         self._data = chem_data
 
     @property
     def Z(self):
-        """
-        Atomic number
-        """
+        """Get atomic number."""
         return self.element_property("Z")
 
     @property
     def atomic_mass(self):
-        """
-        Atomic mass
-        """
+        """Get atomic mass."""
         return self.element_property("atom_mass")
 
     @property
-    def get_chgdescrp_arr(self, elm=""):
+    def get_chgdescrp_arr(self):
         """
-        Get charge descriptors for an element
+        Get charge descriptors for an element.
+
+        Gives 378 array data.
 
         Args:
-        
+
            elm: element name
-           
+
         Returns:
-        
              arr: array value
         """
         arr = []
@@ -103,16 +107,17 @@ class Specie(object):
         return arr
 
     @property
-    def get_descrp_arr(self, elm=""):
+    def get_descrp_arr(self):
         """
-        Get chemical descriptors for an element
+        Get chemical descriptors for an element.
+
+        Gives 438 array data.
 
         Args:
-        
+
            elm: element name
-           
+
         Returns:
-        
              arr: array value
         """
         arr = []
@@ -126,18 +131,15 @@ class Specie(object):
 
     @property
     def atomic_rad(self):
-        """
-        Atomic radii
-        """
+        """Get atomic radii."""
         return self.element_property("atom_rad")
 
     def element_property(self, key=""):
         """
-        Get element property from the list of keys
-        """
-        val = np.nan
-        try:
-            keys = [
+        Get element property from the list of keys.
+
+        These 84 keys are:
+        keys = [
                 "is_halogen",
                 "row",
                 "GV",
@@ -223,11 +225,56 @@ class Specie(object):
                 "mop_eg",
                 "hfus",
             ]
+        """
+        val = np.nan
+        try:
             val = self._data[self.symbol][key]
-        except:
+        except Exception:
             pass
         return val
 
+
+BASIC_FEATURES = [
+    "Z",
+    "coulmn",
+    "row",
+    "X",
+    "atom_rad",
+    "nsvalence",
+    "npvalence",
+    "ndvalence",
+    "nfvalence",
+    "first_ion_en",
+    "elec_aff",
+]
+
+
+@functools.lru_cache(maxsize=None)
+def get_node_attributes(species, atom_features="atomic_number"):
+    """Get specific node features for an element."""
+    feature_sets = ("atomic_number", "basic", "cfid", "cgcnn")
+
+    if atom_features not in feature_sets:
+        raise NotImplementedError(
+            f"atom features must be one of {feature_sets}"
+        )
+
+    if atom_features == "cfid":
+        return Specie(species).get_descrp_arr
+    elif atom_features == "atomic_number":
+        return [Specie(species).element_property("Z")]
+    elif atom_features == "basic":
+        return [
+            Specie(species).element_property(prop) for prop in BASIC_FEATURES
+        ]
+    elif atom_features == "cgcnn":
+        # load from json, key by atomic number
+        key = str(Specie(species).element_property("Z"))
+        with open(cgcnn_feature_json, "r") as f:
+            i = json.load(f)
+        return i[key]
+
+
 """
 if __name__ == "__main__":
     el = Specie("Al")
